==> chaosmesh-model-6.5.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/AWSChaosListFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface AWSChaosListFluent<A extends AWSChaosListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,AWSChaos item);
  public A setToItems(Integer index,AWSChaos item);
  public A addToItems(io.fabric8.chaosmesh.v1alpha1.AWSChaos... items);
  public A addAllToItems(Collection<AWSChaos> items);
  public A removeFromItems(io.fabric8.chaosmesh.v1alpha1.AWSChaos... items);
  public A removeAllFromItems(Collection<AWSChaos> items);
  public A removeMatchingFromItems(Predicate<AWSChaosBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<AWSChaos> getItems();
  public List<AWSChaos> buildItems();
  public AWSChaos buildItem(Integer index);
  public AWSChaos buildFirstItem();
  public AWSChaos buildLastItem();
  public AWSChaos buildMatchingItem(Predicate<AWSChaosBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<AWSChaosBuilder> predicate);
  public A withItems(List<AWSChaos> items);
  public A withItems(io.fabric8.chaosmesh.v1alpha1.AWSChaos... items);
  public Boolean hasItems();
  public AWSChaosListFluent.ItemsNested<A> addNewItem();
  public AWSChaosListFluent.ItemsNested<A> addNewItemLike(AWSChaos item);
  public AWSChaosListFluent.ItemsNested<A> setNewItemLike(Integer index,AWSChaos item);
  public AWSChaosListFluent.ItemsNested<A> editItem(Integer index);
  public AWSChaosListFluent.ItemsNested<A> editFirstItem();
  public AWSChaosListFluent.ItemsNested<A> editLastItem();
  public AWSChaosListFluent.ItemsNested<A> editMatchingItem(Predicate<AWSChaosBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,AWSChaosFluent<AWSChaosListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> chaosmesh-model-6.7.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/AWSChaosListFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface AWSChaosListFluent<A extends AWSChaosListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,AWSChaos item);
  public A setToItems(int index,AWSChaos item);
  public A addToItems(io.fabric8.chaosmesh.v1alpha1.AWSChaos... items);
  public A addAllToItems(Collection<AWSChaos> items);
  public A removeFromItems(io.fabric8.chaosmesh.v1alpha1.AWSChaos... items);
  public A removeAllFromItems(Collection<AWSChaos> items);
  public A removeMatchingFromItems(Predicate<AWSChaosBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<AWSChaos> getItems();
  public List<AWSChaos> buildItems();
  public AWSChaos buildItem(int index);
  public AWSChaos buildFirstItem();
  public AWSChaos buildLastItem();
  public AWSChaos buildMatchingItem(Predicate<AWSChaosBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<AWSChaosBuilder> predicate);
  public A withItems(List<AWSChaos> items);
  public A withItems(io.fabric8.chaosmesh.v1alpha1.AWSChaos... items);
  public Boolean hasItems();
  public AWSChaosListFluent.ItemsNested<A> addNewItem();
  public AWSChaosListFluent.ItemsNested<A> addNewItemLike(AWSChaos item);
  public AWSChaosListFluent.ItemsNested<A> setNewItemLike(int index,AWSChaos item);
  public AWSChaosListFluent.ItemsNested<A> editItem(int index);
  public AWSChaosListFluent.ItemsNested<A> editFirstItem();
  public AWSChaosListFluent.ItemsNested<A> editLastItem();
  public AWSChaosListFluent.ItemsNested<A> editMatchingItem(Predicate<AWSChaosBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,AWSChaosFluent<AWSChaosListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
